@@ -40,6 +40,7 @@ def subprocess_this(fn: Callable) -> Callable:
     def wraper(*args, **kwargs):
         c = Process(target=fn, args=args)
         c.start()
+
     return wraper
 
 
@@ -50,6 +51,7 @@ def thread_this(fn: Callable) -> Callable:
     def wraper(*args, **kwargs):
         c = Thread(target=fn, args=args)
         c.start()
+
     return wraper
 
 
@@ -63,6 +65,7 @@ def timeit(fn: Callable) -> Callable:
         t1 = time.time()
         print(f"[timeit] {fn.__name__}: {(t1-t0)*1000:.2f} ms")
         return r
+
     return wraper
 
 
@@ -84,7 +87,7 @@ def loop_consumer(*topics, package_size=None) -> Callable:
     def wrap_wrap(fn: Callable) -> Callable:
         global data_tmp_eeg_, data_tmp_aux_, package_size_
 
-        arguments = fn.__code__.co_varnames[1:fn.__code__.co_argcount]
+        arguments = fn.__code__.co_varnames[1 : fn.__code__.co_argcount]
 
         def wrap(cls):
             global data_tmp_eeg_, data_tmp_aux_, package_size_
@@ -93,7 +96,7 @@ def loop_consumer(*topics, package_size=None) -> Callable:
                 topics.append('feedback')
 
             # if cls._package_size:
-                # package_size_ = cls._package_size
+            # package_size_ = cls._package_size
 
             with OpenBCIConsumer(host=prop.HOST, topics=topics) as stream:
                 frame = 0
@@ -105,7 +108,10 @@ def loop_consumer(*topics, package_size=None) -> Callable:
 
                     if data.topic == 'feedback':
                         feedback = data.value
-                        if feedback['name'] == cls._feedback.name and feedback['mode'] == 'stimuli2analysis':
+                        if (
+                            feedback['name'] == cls._feedback.name
+                            and feedback['mode'] == 'stimuli2analysis'
+                        ):
                             cls._feedback._on_feedback(**feedback)
 
                         continue
@@ -114,65 +120,96 @@ def loop_consumer(*topics, package_size=None) -> Callable:
                         frame += 1
                         if hasattr(cls, 'buffer_eeg_'):
                             cls.update_buffer(
-                                eeg=data.value['data'], timestamp=min(data.value['context']['timestamp.binary']) - prop.OFFSET)
+                                eeg=data.value['data'],
+                                timestamp=min(
+                                    data.value['context']['timestamp.binary']
+                                )
+                                - prop.OFFSET,
+                            )
                         data_ = data.value['data']
                     elif data.topic == 'aux':
                         frame += 1
                         if hasattr(cls, 'buffer_aux_'):
                             cls.update_buffer(
-                                aux=data.value['data'], timestamp=min(data.value['context']['timestamp.binary']) - prop.OFFSET)
+                                aux=data.value['data'],
+                                timestamp=min(
+                                    data.value['context']['timestamp.binary']
+                                )
+                                - prop.OFFSET,
+                            )
                         data_ = data.value['data']
                     else:
                         data_ = data.value
 
                     # latency calculated with `timestamp.binary`
                     if data.topic in ['eeg', 'aux']:
-                        latency = (datetime.now() - datetime.fromtimestamp(
-                            min(data.value['context']['timestamp.binary']) - prop.OFFSET)).total_seconds() * 1000
+                        latency = (
+                            datetime.now()
+                            - datetime.fromtimestamp(
+                                min(
+                                    data.value['context']['timestamp.binary']
+                                )
+                                - prop.OFFSET
+                            )
+                        ).total_seconds() * 1000
+
+                        samples = data.value['context']['sample_ids']
+
                     else:
                         # latency calculated with kafka timestamp
-                        latency = (datetime.now(
-                        ) - datetime.fromtimestamp(data.timestamp / 1000)).total_seconds() * 1000
+                        latency = (
+                            datetime.now()
+                            - datetime.fromtimestamp(data.timestamp / 1000)
+                        ).total_seconds() * 1000
+
+                        samples = None
 
                     if package_size_ and (data.topic in ['eeg', 'aux']):
 
                         if data.topic == 'eeg':
                             if data_tmp_eeg_ is None:
-                                data_tmp_eeg_ = np.zeros(
-                                    (data_.shape[0], 0))
+                                data_tmp_eeg_ = np.zeros((data_.shape[0], 0))
                             data_tmp_eeg_ = np.concatenate(
-                                [data_tmp_eeg_, data_], axis=1)
+                                [data_tmp_eeg_, data_], axis=1
+                            )
                             d = data_tmp_eeg_
                         elif data.topic == 'aux':
                             if data_tmp_aux_ is None:
                                 data_tmp_aux_ = np.zeros((data_.shape[0], 0))
                             data_tmp_aux_ = np.concatenate(
-                                [data_tmp_aux_, data_], axis=1)
+                                [data_tmp_aux_, data_], axis=1
+                            )
                             d = data_tmp_aux_
 
-                        kwargs = {'data': d,
-                                  'kafka_stream': data,
-                                  'topic': data.topic,
-                                  'frame': frame,
-                                  'latency': latency,
-                                  }
-                        n = (package_size_ // prop.STREAMING_PACKAGE_SIZE)
+                        kwargs = {
+                            'data': d,
+                            'kafka_stream': data,
+                            'topic': data.topic,
+                            'frame': frame,
+                            'latency': latency,
+                            'samples': samples,
+                        }
+                        n = package_size_ // prop.STREAMING_PACKAGE_SIZE
                         if frame % n == 0:
                             fn(*[cls] + [kwargs[v] for v in arguments])
-                        # else:
+                            # else:
                             if data.topic == 'eeg':
                                 data_tmp_eeg_ = np.zeros((data_.shape[0], 0))
                             elif data.topic == 'aux':
                                 data_tmp_aux_ = np.zeros((data_.shape[0], 0))
                     else:
-                        kwargs = {'data': data_,
-                                  'kafka_stream': data,
-                                  'topic': data.topic,
-                                  'frame': frame,
-                                  'latency': latency,
-                                  }
+                        kwargs = {
+                            'data': data_,
+                            'kafka_stream': data,
+                            'topic': data.topic,
+                            'frame': frame,
+                            'latency': latency,
+                            'samples': samples,
+                        }
                         fn(*[cls] + [kwargs[v] for v in arguments])
+
         return wrap
+
     return wrap_wrap
 
 
@@ -186,7 +223,7 @@ def fake_loop_consumer(*topics, package_size=None) -> Callable:
     # ----------------------------------------------------------------------
     def wrap_wrap(fn: Callable) -> Callable:
 
-        arguments = fn.__code__.co_varnames[1:fn.__code__.co_argcount]
+        arguments = fn.__code__.co_varnames[1 : fn.__code__.co_argcount]
 
         def wrap(cls):
             frame = 0
@@ -198,8 +235,9 @@ def fake_loop_consumer(*topics, package_size=None) -> Callable:
                 num_data = int(prop.STREAMING_PACKAGE_SIZE)
                 num_data = random.randint(num_data - 10, num_data + 10)
 
-                eeg = 150 * np.random.normal(0, 0.2, size=(
-                    len(prop.CHANNELS), num_data))
+                eeg = 150 * np.random.normal(
+                    0, 0.2, size=(len(prop.CHANNELS), num_data)
+                )
 
                 if prop.BOARDMODE == 'default':
                     aux = np.random.normal(0, 0.2, size=(3, num_data))
@@ -231,52 +269,64 @@ def fake_loop_consumer(*topics, package_size=None) -> Callable:
                 if 'eeg' in topics:
                     if hasattr(cls, 'buffer_eeg'):
                         cls.update_buffer(
-                            eeg=eeg, timestamp=data.value['timestamp'].timestamp())
+                            eeg=eeg,
+                            timestamp=data.value['timestamp'].timestamp(),
+                        )
 
-                    kwargs = {'data': eeg,
-                              'kafka_stream': data,
-                              'topic': 'eeg',
-                              'frame': frame,
-                              'latency': 0,
-                              }
+                    kwargs = {
+                        'data': eeg,
+                        'kafka_stream': data,
+                        'topic': 'eeg',
+                        'frame': frame,
+                        'latency': 0,
+                    }
                     fn(*[cls] + [kwargs[v] for v in arguments])
 
                 if 'aux' in topics:
                     if hasattr(cls, 'buffer_aux'):
                         cls.update_buffer(
-                            aux=aux, timestamp=data.value['timestamp'].timestamp())
+                            aux=aux,
+                            timestamp=data.value['timestamp'].timestamp(),
+                        )
 
-                    kwargs = {'data': aux,
-                              'kafka_stream': data,
-                              'topic': 'eeg',
-                              'frame': frame,
-                              'latency': 0,
-                              }
+                    kwargs = {
+                        'data': aux,
+                        'kafka_stream': data,
+                        'topic': 'eeg',
+                        'frame': frame,
+                        'latency': 0,
+                    }
                     fn(*[cls] + [kwargs[v] for v in arguments])
 
                 if 'marker' in topics:
                     if np.random.random() > 0.9:
                         data.value['timestamp'] = datetime.now()
                         # data.value['datetime'] = datetime.now()
-                        data.value['context']['timestamp.binary'] = datetime.now()
+                        data.value['context'][
+                            'timestamp.binary'
+                        ] = datetime.now()
                         # data.value['data'] = chr(
-                            # np.random.choice(range(ord('A'), ord('Z') + 1)))
+                        # np.random.choice(range(ord('A'), ord('Z') + 1)))
                         # data.value['data'] = random.choice(
-                            # ['Right', 'Left', 'Up', 'Bottom'])
+                        # ['Right', 'Left', 'Up', 'Bottom'])
                         data.value['marker'] = random.choice(['MARKER'])
 
-                        kwargs = {'data': data.value,
-                                  'kafka_stream': data,
-                                  'topic': 'marker',
-                                  'frame': frame,
-                                  'latency': 0,
-                                  }
+                        kwargs = {
+                            'data': data.value,
+                            'kafka_stream': data,
+                            'topic': 'marker',
+                            'frame': frame,
+                            'latency': 0,
+                        }
                         fn(*[cls] + [kwargs[v] for v in arguments])
 
-                while time.time() < (t0 + 1 / (prop.SAMPLE_RATE / prop.STREAMING_PACKAGE_SIZE)):
+                while time.time() < (
+                    t0 + 1 / (prop.SAMPLE_RATE / prop.STREAMING_PACKAGE_SIZE)
+                ):
                     time.sleep(0.0001)
 
         return wrap
+
     return wrap_wrap
 
 
@@ -288,7 +338,7 @@ def marker_slicing(markers, t0, t1):
 
     def wrap_wrap(fn):
 
-        arguments = fn.__code__.co_varnames[1:fn.__code__.co_argcount]
+        arguments = fn.__code__.co_varnames[1 : fn.__code__.co_argcount]
 
         def wrap(cls):
             cls._target_marker = []
@@ -298,12 +348,18 @@ def marker_slicing(markers, t0, t1):
 
                 if topic == 'marker':
                     # if data['marker'] in markers:
-                        # cls._target_marker.append(
-                            # [data['marker'], kafka_stream.value['datetime']])
+                    # cls._target_marker.append(
+                    # [data['marker'], kafka_stream.value['datetime']])
 
-                    if any([bool(re.match(mkr, data['marker'])) for mkr in markers]):
+                    if any(
+                        [
+                            bool(re.match(mkr, data['marker']))
+                            for mkr in markers
+                        ]
+                    ):
                         cls._target_marker.append(
-                            [data['marker'], kafka_stream.value['datetime']])
+                            [data['marker'], kafka_stream.value['datetime']]
+                        )
 
                 if len(cls._target_marker) < 3:
                     return
@@ -312,35 +368,45 @@ def marker_slicing(markers, t0, t1):
 
                     # marker, target = target
 
-                    last_buffer_timestamp = cls.buffer_aux_timestamp[-1] - prop.OFFSET
-                    last_target_timestamp = (datetime.fromtimestamp(
-                        target[0][1]) + timedelta(seconds=t1)).timestamp()
+                    last_buffer_timestamp = (
+                        cls.buffer_aux_timestamp[-1] - prop.OFFSET
+                    )
+                    last_target_timestamp = (
+                        datetime.fromtimestamp(target[0][1])
+                        + timedelta(seconds=t1)
+                    ).timestamp()
 
                     if last_buffer_timestamp > last_target_timestamp:
-                    # if True:
+                        # if True:
 
                         _marker, _target = target.pop(0)
 
                         argmin = np.abs(
-                            cls.buffer_aux_timestamp - _target).argmin()
+                            cls.buffer_aux_timestamp - _target
+                        ).argmin()
 
                         start = int((prop.SAMPLE_RATE) * t0)
                         stop = int((prop.SAMPLE_RATE) * t1)
 
-                        t = cls.buffer_aux_timestamp[argmin +
-                                                     start: argmin + stop]
+                        t = cls.buffer_aux_timestamp[
+                            argmin + start : argmin + stop
+                        ]
                         eeg = cls.buffer_eeg_[
-                            :, argmin + start: argmin + stop]
+                            :, argmin + start : argmin + stop
+                        ]
                         aux = cls.buffer_aux_[
-                            :, argmin + start: argmin + stop]
+                            :, argmin + start : argmin + stop
+                        ]
 
-                        kwargs = {'eeg': eeg,
-                                  'aux': aux,
-                                  'timestamp': t,
-                                  'marker_datetime': _target,
-                                  'marker': _marker,
-                                  'latency': latency,
-                                  }
+                        kwargs = {
+                            'eeg': eeg,
+                            'aux': aux,
+                            'timestamp': t,
+                            'marker_datetime': _target,
+                            'marker': _marker,
+                            'latency': latency,
+                            # 'samples': samples,
+                        }
 
                         fn(*[cls] + [kwargs[v] for v in arguments])
 
@@ -348,8 +414,11 @@ def marker_slicing(markers, t0, t1):
                         logging.warning('Date too old to synchronize')
                         logging.warning(f'Offset: {prop.OFFSET}')
                         logging.warning(
-                            f'{datetime.fromtimestamp(last_buffer_timestamp), datetime.fromtimestamp(last_target_timestamp)}')
+                            f'{datetime.fromtimestamp(last_buffer_timestamp), datetime.fromtimestamp(last_target_timestamp)}'
+                        )
 
             marker_slicing_(cls)
+
         return wrap
+
     return wrap_wrap
