@@ -8,16 +8,23 @@ import os
 import json
 import time
 import types
+import pickle
 import logging
 import requests
 
-from openbci_stream.acquisition import Cyton, CytonBase, wifi, restart_services
+from openbci_stream.acquisition import (
+    Cyton,
+    CytonBase,
+    wifi,
+    restart_services,
+)
 from PySide6.QtCore import Qt, Signal, QThread, Slot, QTimer
 from PySide6.QtGui import QCursor, QIcon
 from PySide6.QtWidgets import QApplication
 
 from ..dialogs import Dialogs
 from ...extensions import properties as prop
+
 # from ...extensions.data_analysis.utils import thread_this
 
 
@@ -41,27 +48,38 @@ class OpenBCIThread(QThread):
 
         if sum(self.channels_assignations) != len(self.montage):
             self.connection_fail.emit(
-                ['* The number of electrodes defined in montage not correspon with the number of boards available.'])
+                [
+                    '* The number of electrodes defined in montage not correspon with the number of boards available.'
+                ]
+            )
             return
 
         try:
-            self.openbci = Cyton(self.mode,
-                                 self.endpoint,
-                                 host=self.host,
-                                 capture_stream=False,
-                                 daisy=self.daisy,
-                                 montage=self.montage,
-                                 streaming_package_size=self.streaming_package_size,
-                                 number_of_channels=self.channels_assignations,
-                                 )
+            self.openbci = Cyton(
+                self.mode,
+                self.endpoint,
+                host=self.host,
+                capture_stream=False,
+                daisy=self.daisy,
+                montage=self.montage,
+                streaming_package_size=self.streaming_package_size,
+                number_of_channels=self.channels_assignations,
+            )
 
         except Exception as msg:
             logging.warning(msg)
             self.connection_fail.emit([])
             return
 
-        self.session_settings(self.montage, self.bias,
-                              self.gain, self.srb1, self.adsinput, self.srb2, self.sample_rate)
+        self.session_settings(
+            self.montage,
+            self.bias,
+            self.gain,
+            self.srb1,
+            self.adsinput,
+            self.srb2,
+            self.sample_rate,
+        )
 
         if getattr(self.openbci, 'is_recycled', False):
             self.connected = True
@@ -74,7 +92,8 @@ class OpenBCIThread(QThread):
             self.openbci.command(self.boardmode)
         except TimeoutError:
             self.connection_fail.emit(
-                ['* OpenBCI board could not be connected the same network.'])
+                ['* OpenBCI board could not be connected the same network.']
+            )
             return
 
         # Some time this command not take effect
@@ -83,8 +102,7 @@ class OpenBCIThread(QThread):
             response = self.openbci.command(self.boardmode)
             if response and all([b'Success:' in r for r in response]):
                 self.boardmode_s = CytonBase.BOARD_MODE_VALUE[self.boardmode]
-                logging.info(
-                    f'Bardmode setted in "{self.boardmode_s}" mode')
+                logging.info(f'Bardmode setted in "{self.boardmode_s}" mode')
                 boardmode_setted = True
                 break
             time.sleep(0.1)
@@ -94,26 +112,28 @@ class OpenBCIThread(QThread):
             logging.warning('Boardmode not setted!')
             self.boardmode_s = None
         # self.session_settings(self.montage, self.bias,
-                              # self.gain, self.srb1, self.adsinput, self.srb2, self.sample_rate)
+        # self.gain, self.srb1, self.adsinput, self.srb2, self.sample_rate)
 
         if self.checkBox_send_leadoff:
             self.openbci.leadoff_impedance(
-                self.montage, pchan=self.pchan, nchan=self.nchan)
+                self.montage, pchan=self.pchan, nchan=self.nchan
+            )
 
         if self.checkBox_test_signal:
             test_signal = self.comboBox_test_signal
             test_signal = getattr(
-                CytonBase, f"TEST_{test_signal.replace(' ', '_')}")
+                CytonBase, f"TEST_{test_signal.replace(' ', '_')}"
+            )
             self.openbci.command(test_signal)
 
         # else:
-            # used_channels = set(self.montage.keys())
-            # if used_channels:
-                # self.openbci.activate_channel(used_channels)
-            # # all_channels = set(range(1, 17 if prop.DAISY else 9))
-            # # deactivated = all_channels.difference(used_channels)
-            # # if deactivated:
-                # # self.openbci.deactivate_channel(deactivated)
+        # used_channels = set(self.montage.keys())
+        # if used_channels:
+        # self.openbci.activate_channel(used_channels)
+        # # all_channels = set(range(1, 17 if prop.DAISY else 9))
+        # # deactivated = all_channels.difference(used_channels)
+        # # if deactivated:
+        # # self.openbci.deactivate_channel(deactivated)
 
         self.start_stream_()
 
@@ -133,13 +153,24 @@ class OpenBCIThread(QThread):
                 if 'NoBrokersAvailable' in str(e):
 
                     self.connection_fail.emit(
-                        ['* Kafka is not running on the remote acquisition system.'])
+                        [
+                            '* Kafka is not running on the remote acquisition system.'
+                        ]
+                    )
 
     # ----------------------------------------------------------------------
     def session_settings(self, *args) -> None:
         """Create a session setting to reuse it after an impedance measurement."""
         if hasattr(self, 'last_settings'):
-            channels, bias, gain, srb1, adsinput, srb2, sample_rate = self.last_settings
+            (
+                channels,
+                bias,
+                gain,
+                srb1,
+                adsinput,
+                srb2,
+                sample_rate,
+            ) = self.last_settings
         elif args:
             self.last_settings = args
             channels, bias, gain, srb1, adsinput, srb2, sample_rate = args
@@ -152,13 +183,15 @@ class OpenBCIThread(QThread):
         if self.checkBox_default_settings:
             self.openbci.command(self.openbci.DEFAULT_CHANNELS_SETTINGS)
         else:
-            self.openbci.channel_settings(channels, power_down=CytonBase.POWER_DOWN_ON,
-                                          gain=gain,
-                                          input_type=adsinput,
-                                          bias=bias,
-                                          srb2=[f'{s}'.encode()
-                                                for s in srb2],
-                                          srb1=srb1)
+            self.openbci.channel_settings(
+                channels,
+                power_down=CytonBase.POWER_DOWN_ON,
+                gain=gain,
+                input_type=adsinput,
+                bias=bias,
+                srb2=[f'{s}'.encode() for s in srb2],
+                srb1=srb1,
+            )
 
     # ----------------------------------------------------------------------
     def disconnect(self) -> None:
@@ -185,7 +218,8 @@ class Connection:
         # self.parent.pushButton_disconnect.hide()
         self.openbci = OpenBCIThread()
         self.openbci.streaming = lambda: getattr(
-            self.core, 'streaming', False)
+            self.core, 'streaming', False
+        )
 
         self.openbci.connection_ok.connect(self.connection_ok)
         self.openbci.connection_fail.connect(self.connection_fail)
@@ -236,17 +270,17 @@ class Connection:
         if json.loads(os.getenv('BCISTREAM_RASPAD')):
             try:
                 restart_services(prop.HOST)
-                logging.warning(
-                    f'Restarting services on {prop.HOST}')
+                logging.warning(f'Restarting services on {prop.HOST}')
             except:
                 logging.warning(
-                    f'Impossible to restart services on {prop.HOST}')
+                    f'Impossible to restart services on {prop.HOST}'
+                )
 
     # ----------------------------------------------------------------------
     def on_focus(self) -> None:
         """Try to autoconnect."""
         # if getattr(self.core, 'streaming', False) and not self.openbci.connected:
-            # self.openbci_connect()
+        # self.openbci_connect()
 
         for i in range(1, 5):
             combo = getattr(self.parent_frame, f'comboBox_ip{i}')
@@ -271,35 +305,42 @@ class Connection:
         """Connect events."""
         self.parent_frame.pushButton_connect.clicked.connect(self.on_connect)
         self.parent_frame.comboBox_connection_mode.activated.connect(
-            self.update_connections)
+            self.update_connections
+        )
         # self.parent_frame.comboBox_host.textActivated.connect(
-            # self.load_config)
+        # self.load_config)
 
         # CheckWiFiModule
         for i in range(1, 5):
             combo = getattr(self.parent_frame, f'comboBox_ip{i}')
             target = getattr(self.parent_frame, f'pushButton_ip{i}')
             # combo.textActivated.connect(
-                # self.request_wifi(i, target, combo))
-            target.setStyleSheet("""*{
+            # self.request_wifi(i, target, combo))
+            target.setStyleSheet(
+                """*{
                 background-color: transparent !important;
-                 }""")
+                 }"""
+            )
 
-            getattr(self.parent_frame, f'pushButton_update_wifi{i}').clicked.connect(
-                self.request_wifi(i, target, combo))
+            getattr(
+                self.parent_frame, f'pushButton_update_wifi{i}'
+            ).clicked.connect(self.request_wifi(i, target, combo))
 
-            getattr(self.parent_frame, f'checkBox_board{i}').stateChanged.connect(
-                self.wrap_clear_text(target))
+            getattr(
+                self.parent_frame, f'checkBox_board{i}'
+            ).stateChanged.connect(self.wrap_clear_text(target))
 
             # check = getattr(self.parent_frame, f'checkBox_board{i}')
             # if check.isChecked():
-                # self.request_wifi(i, target, combo)()
+            # self.request_wifi(i, target, combo)()
 
     # ----------------------------------------------------------------------
     def wrap_clear_text(self, target):
         """"""
+
         def wrapped():
             target.setText('')
+
         return wrapped
 
     # ----------------------------------------------------------------------
@@ -317,19 +358,25 @@ class Connection:
             combo.valid = False
 
             try:
-                target.setStyleSheet("""*{
+                target.setStyleSheet(
+                    """*{
                 background-color: transparent !important;
-                 }""")
+                 }"""
+                )
 
                 response = wifi(
-                    self.parent_frame.comboBox_host.currentText(), ip)
+                    self.parent_frame.comboBox_host.currentText(), ip
+                )
 
                 if response['board_connected']:
                     target.setText(
-                        f"connected ({response['num_channels']} ch)")
+                        f"connected ({response['num_channels']} ch)"
+                    )
                     target.setProperty('class', 'success icon_button')
                     combo.valid = True
-                    self.channels_assignations[board] = response['num_channels']
+                    self.channels_assignations[board] = response[
+                        'num_channels'
+                    ]
                 else:
                     target.setText('connected (no board detected)')
                     target.setProperty('class', 'danger icon_button')
@@ -341,9 +388,11 @@ class Connection:
                 target.update()
 
             except:
-                target.setStyleSheet("""*{
+                target.setStyleSheet(
+                    """*{
                 background-color: transparent !important;
-                 }""")
+                 }"""
+                )
                 target.setText('No WiFi module found')
                 target.setProperty('class', 'danger icon_button')
                 target.style().unpolish(target)
@@ -355,33 +404,50 @@ class Connection:
             target.show()
             if not no_cursor:
                 QApplication.restoreOverrideCursor()
+
         return inset
 
     # ----------------------------------------------------------------------
     def update_connections(self) -> None:
         """Set widgets for connection modes."""
-        if 'serial' in self.parent_frame.comboBox_connection_mode.currentText().lower():
+        if (
+            'serial'
+            in self.parent_frame.comboBox_connection_mode.currentText().lower()
+        ):
 
-            for index in range(1, self.parent_frame.comboBox_sample_rate.count()):
-                self.parent_frame.comboBox_sample_rate.model().item(index).setEnabled(False)
+            for index in range(
+                1, self.parent_frame.comboBox_sample_rate.count()
+            ):
+                self.parent_frame.comboBox_sample_rate.model().item(
+                    index
+                ).setEnabled(False)
             if self.parent_frame.comboBox_sample_rate.currentIndex() >= 1:
                 self.parent_frame.comboBox_sample_rate.setCurrentIndex(0)
 
-            for index in range(3, self.parent_frame.comboBox_streaming_sample_rate.count()):
+            for index in range(
+                3, self.parent_frame.comboBox_streaming_sample_rate.count()
+            ):
                 self.parent_frame.comboBox_streaming_sample_rate.model().item(
-                    index).setEnabled(False)
-            if self.parent_frame.comboBox_streaming_sample_rate.currentIndex() >= 3:
+                    index
+                ).setEnabled(
+                    False
+                )
+            if (
+                self.parent_frame.comboBox_streaming_sample_rate.currentIndex()
+                >= 3
+            ):
                 self.parent_frame.comboBox_streaming_sample_rate.setCurrentIndex(
-                    2)
+                    2
+                )
 
             # self.parent_frame.label_port_ip.setText('Port')
             for i in range(1, 5):
                 getattr(self.parent_frame, f'comboBox_ip{i}').hide()
                 getattr(self.parent_frame, f'comboBox_port{i}').show()
-                getattr(self.parent_frame,
-                        f'pushButton_update_wifi{i}').hide()
-                getattr(self.parent_frame,
-                        f'pushButton_ip{i}').hide()
+                getattr(
+                    self.parent_frame, f'pushButton_update_wifi{i}'
+                ).hide()
+                getattr(self.parent_frame, f'pushButton_ip{i}').hide()
             # self.parent_frame.comboBox_ip.hide()
             # self.parent_frame.comboBox_port.show()
             self.parent_frame.label_latency.setEnabled(False)
@@ -389,20 +455,30 @@ class Connection:
 
         else:
 
-            for index in range(1, self.parent_frame.comboBox_sample_rate.count()):
-                self.parent_frame.comboBox_sample_rate.model().item(index).setEnabled(True)
+            for index in range(
+                1, self.parent_frame.comboBox_sample_rate.count()
+            ):
+                self.parent_frame.comboBox_sample_rate.model().item(
+                    index
+                ).setEnabled(True)
 
-            for index in range(3, self.parent_frame.comboBox_streaming_sample_rate.count()):
-                self.parent_frame.comboBox_streaming_sample_rate.model().item(index).setEnabled(True)
+            for index in range(
+                3, self.parent_frame.comboBox_streaming_sample_rate.count()
+            ):
+                self.parent_frame.comboBox_streaming_sample_rate.model().item(
+                    index
+                ).setEnabled(
+                    True
+                )
 
             # self.parent_frame.label_port_ip.setText('IP')
             for i in range(1, 5):
                 getattr(self.parent_frame, f'comboBox_ip{i}').show()
                 getattr(self.parent_frame, f'comboBox_port{i}').hide()
-                getattr(self.parent_frame,
-                        f'pushButton_update_wifi{i}').show()
-                getattr(self.parent_frame,
-                        f'pushButton_ip{i}').show()
+                getattr(
+                    self.parent_frame, f'pushButton_update_wifi{i}'
+                ).show()
+                getattr(self.parent_frame, f'pushButton_ip{i}').show()
             # self.parent_frame.comboBox_ip.show()
             # self.parent_frame.comboBox_port.hide()
             self.parent_frame.label_latency.setEnabled(True)
@@ -412,7 +488,10 @@ class Connection:
     def autoconnect(self) -> None:
         """"""
         self.core.calculate_offset()
-        if getattr(self.core, 'streaming', False) and not self.openbci.connected:
+        if (
+            getattr(self.core, 'streaming', False)
+            and not self.openbci.connected
+        ):
             self.on_focus()
             if self.openbci_connect():
                 self.connection_ok()
@@ -422,31 +501,52 @@ class Connection:
         """Event to handle connection."""
 
         self.core.calculate_offset()
-        if getattr(self.core, 'streaming', False) and not self.openbci.connected:
+        if (
+            getattr(self.core, 'streaming', False)
+            and not self.openbci.connected
+        ):
             self.openbci_connect()
         else:
             if toggled:  # Connect
                 QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
                 self.core.update_kafka(
-                    self.parent_frame.comboBox_host.currentText())
+                    self.parent_frame.comboBox_host.currentText()
+                )
                 self.restart_services()
                 self.openbci_connect()
 
-            else:   # Disconnect
+            else:  # Disconnect
                 self.openbci.disconnect()
 
     # ----------------------------------------------------------------------
     def openbci_connect(self) -> bool:
         """Recollect values from GUI."""
-        if 'serial' in self.parent_frame.comboBox_connection_mode.currentText().lower():
+        if (
+            'serial'
+            in self.parent_frame.comboBox_connection_mode.currentText().lower()
+        ):
             mode = 'serial'
-            endpoint = [getattr(self.parent_frame, f'comboBox_port{i}').currentText() for i in range(
-                1, 5) if getattr(getattr(self.parent_frame, f'comboBox_ip{i}'), 'valid', False)]
+            endpoint = [
+                getattr(self.parent_frame, f'comboBox_port{i}').currentText()
+                for i in range(1, 5)
+                if getattr(
+                    getattr(self.parent_frame, f'comboBox_ip{i}'),
+                    'valid',
+                    False,
+                )
+            ]
             os.environ['BCISTREAM_CONNECTION'] = json.dumps('serial')
         else:
             mode = 'wifi'
-            endpoint = [getattr(self.parent_frame, f'comboBox_ip{i}').currentText() for i in range(
-                1, 5) if getattr(getattr(self.parent_frame, f'comboBox_ip{i}'), 'valid', False)]
+            endpoint = [
+                getattr(self.parent_frame, f'comboBox_ip{i}').currentText()
+                for i in range(1, 5)
+                if getattr(
+                    getattr(self.parent_frame, f'comboBox_ip{i}'),
+                    'valid',
+                    False,
+                )
+            ]
             os.environ['BCISTREAM_CONNECTION'] = json.dumps('wifi')
 
         host = self.parent_frame.comboBox_host.currentText()
@@ -454,7 +554,9 @@ class Connection:
         sample_rate = self.parent_frame.comboBox_sample_rate.currentText()
         sample_rate = getattr(CytonBase, f"SAMPLE_RATE_{sample_rate}SPS")
 
-        streaming_sample_rate = self.parent_frame.comboBox_streaming_sample_rate.currentText()
+        streaming_sample_rate = (
+            self.parent_frame.comboBox_streaming_sample_rate.currentText()
+        )
 
         boardmode = self.parent_frame.comboBox_boardmode.currentText()
         boardmode = getattr(CytonBase, f"BOARD_MODE_{boardmode}")
@@ -514,21 +616,33 @@ class Connection:
                 del self.channels_assignations[i]
 
         self.openbci.channels_assignations = [
-            e[1] for e in sorted(list(self.channels_assignations.items()))]
+            e[1] for e in sorted(list(self.channels_assignations.items()))
+        ]
 
         self.openbci.daisy = [
-            True if chs == 16 else False for chs in self.openbci.channels_assignations]
+            True if chs == 16 else False
+            for chs in self.openbci.channels_assignations
+        ]
         os.environ['BCISTREAM_DAISY'] = json.dumps(all(self.openbci.daisy))
         os.environ['BCISTREAM_CHANNELS_BY_BOARD'] = json.dumps(
-            self.openbci.channels_assignations)
+            self.openbci.channels_assignations
+        )
 
         # self.openbci.checkBox_send_leadoff = self.parent_frame.checkBox_send_leadoff.isChecked()
-        self.openbci.checkBox_send_leadoff = self.parent_frame.groupBox_leadoff_impedance.isChecked()
+        self.openbci.checkBox_send_leadoff = (
+            self.parent_frame.groupBox_leadoff_impedance.isChecked()
+        )
         # self.openbci.checkBox_default_settings = self.parent_frame.checkBox_default_settings.isChecked()
-        self.openbci.checkBox_default_settings = not self.parent_frame.groupBox_settings.isChecked()
+        self.openbci.checkBox_default_settings = (
+            not self.parent_frame.groupBox_settings.isChecked()
+        )
 
-        self.openbci.checkBox_test_signal = self.parent_frame.checkBox_test_signal.isChecked()
-        self.openbci.comboBox_test_signal = self.parent_frame.comboBox_test_signal.currentText()
+        self.openbci.checkBox_test_signal = (
+            self.parent_frame.checkBox_test_signal.isChecked()
+        )
+        self.openbci.comboBox_test_signal = (
+            self.parent_frame.comboBox_test_signal.currentText()
+        )
 
         self.parent_frame.pushButton_connect.setText('Connecting...')
         self.parent_frame.pushButton_connect.setEnabled(False)
@@ -541,7 +655,8 @@ class Connection:
     def update_environ(self) -> None:
         """Update environment variables."""
         os.environ['BCISTREAM_HOST'] = json.dumps(
-            self.parent_frame.comboBox_host.currentText())
+            self.parent_frame.comboBox_host.currentText()
+        )
 
         sps = self.parent_frame.comboBox_sample_rate.currentText()
         if 'k' in sps.lower():
@@ -550,10 +665,14 @@ class Connection:
             sps = int(sps)
         os.environ['BCISTREAM_SAMPLE_RATE'] = json.dumps(sps)
         os.environ['BCISTREAM_STREAMING_PACKAGE_SIZE'] = json.dumps(
-            int(self.parent_frame.comboBox_streaming_sample_rate.currentText()))
+            int(
+                self.parent_frame.comboBox_streaming_sample_rate.currentText()
+            )
+        )
 
         os.environ['BCISTREAM_BOARDMODE'] = json.dumps(
-            self.parent_frame.comboBox_boardmode.currentText().lower())
+            self.parent_frame.comboBox_boardmode.currentText().lower()
+        )
 
     # ----------------------------------------------------------------------
     # @Slot()
@@ -576,19 +695,31 @@ class Connection:
             checks.extend(reasons)
 
         else:
-            if 'serial' in self.parent_frame.comboBox_connection_mode.currentText().lower():
-                checks.extend(['* Check that USB dongle were connected.',
-                               '* Verify serial permissions.',
-                               ])
+            if (
+                'serial'
+                in self.parent_frame.comboBox_connection_mode.currentText().lower()
+            ):
+                checks.extend(
+                    [
+                        '* Check that USB dongle were connected.',
+                        '* Verify serial permissions.',
+                    ]
+                )
             else:
-                checks.extend([f"* The WiFi moudule could be running in a different IP",
-                               ])
+                checks.extend(
+                    [
+                        f"* The WiFi moudule could be running in a different IP",
+                    ]
+                )
 
             if self.parent_frame.comboBox_host.currentText() != 'localhost':
-                checks.extend([f'* The server could not be running, or running on a different IP that {self.parent_frame.comboBox_host.currentText()}',
-                               '* This machine must have access to the server or running on the same network.',
-                               '* The daemons `stream_eeg` `stream_rpyc` could not be running',  # todo
-                               ])
+                checks.extend(
+                    [
+                        f'* The server could not be running, or running on a different IP that {self.parent_frame.comboBox_host.currentText()}',
+                        '* This machine must have access to the server or running on the same network.',
+                        '* The daemons `stream_eeg` `stream_rpyc` could not be running',  # todo
+                    ]
+                )
 
             if hasattr(self.core, 'conection_message'):
                 checks.extend([self.core.conection_message])
@@ -596,7 +727,8 @@ class Connection:
 
         checks = '\n'.join(checks)
         Dialogs.critical_message(
-            self.parent_frame, 'Connection error', f"{checks}")
+            self.parent_frame, 'Connection error', f"{checks}"
+        )
 
         self.parent_frame.pushButton_connect.setText('Connect')
         self.parent_frame.pushButton_connect.setEnabled(True)
