@@ -32,14 +32,16 @@ class Records:
         self.current_signal = None
 
         self.records_dir = os.path.join(
-            os.getenv('BCISTREAM_HOME'), 'records')
+            os.getenv('BCISTREAM_HOME'), 'records'
+        )
         os.makedirs(self.records_dir, exist_ok=True)
 
         self.connect()
 
         self.parent_frame.label_records_path.setText(self.records_dir)
         self.parent_frame.label_records_path.setStyleSheet(
-            '*{font-family: "DejaVu Sans Mono";}')
+            '*{font-family: "DejaVu Sans Mono";}'
+        )
 
         self.parent_frame.widget_record.hide()
 
@@ -52,19 +54,25 @@ class Records:
     def connect(self) -> None:
         """Connect events."""
         self.parent_frame.tableWidget_records.itemDoubleClicked.connect(
-            self.load_file)
+            self.load_file
+        )
         self.parent_frame.horizontalSlider_record.valueChanged.connect(
-            self.update_record_time)
+            self.update_record_time
+        )
         self.parent_frame.pushButton_play_signal.clicked.connect(
-            self.stream_record)
+            self.stream_record
+        )
         self.parent_frame.pushButton_record.toggled.connect(
-            self.record_signal)
+            self.record_signal
+        )
 
         self.parent_frame.tableWidget_records.itemChanged.connect(
-            self.record_renamed)
+            self.record_renamed
+        )
 
         self.parent_frame.pushButton_remove_record.clicked.connect(
-            self.remove_record)
+            self.remove_record
+        )
 
     # ----------------------------------------------------------------------
     def remove_record(self) -> None:
@@ -73,11 +81,15 @@ class Records:
         if row < 0:
             return
         filename = self.parent_frame.tableWidget_records.item(
-            row, 2).previous_name
+            row, 2
+        ).previous_name
 
         if Dialogs.remove_file_warning(self.parent_frame, filename):
-            os.remove(os.path.join(self.records_dir,
-                                   f'{filename.replace(":", "_")}.h5'))
+            os.remove(
+                os.path.join(
+                    self.records_dir, f'{filename.replace(":", "_")}.h5'
+                )
+            )
             self.load_records()
 
     # ----------------------------------------------------------------------
@@ -90,8 +102,10 @@ class Records:
         new_name = item.text()
 
         if old_name != new_name:
-            shutil.move(os.path.join(self.records_dir, f'{old_name}.h5'),
-                        os.path.join(self.records_dir, f'{new_name}.h5'))
+            shutil.move(
+                os.path.join(self.records_dir, f'{old_name}.h5'),
+                os.path.join(self.records_dir, f'{new_name}.h5'),
+            )
             self.load_records()
 
     # ----------------------------------------------------------------------
@@ -101,9 +115,11 @@ class Records:
         self.parent_frame.tableWidget_records.setRowCount(0)
         self.parent_frame.tableWidget_records.setColumnCount(3)
         self.parent_frame.tableWidget_records.setHorizontalHeaderLabels(
-            ['Duration', 'Datetime', 'Name'])
-        records = filter(lambda s: s.endswith(
-            'h5'), os.listdir(self.records_dir))
+            ['Duration', 'Datetime', 'Name']
+        )
+        records = filter(
+            lambda s: s.endswith('h5'), os.listdir(self.records_dir)
+        )
 
         i = 0
         for filename in records:
@@ -116,7 +132,9 @@ class Records:
             for j, value in enumerate(metadata):
                 item = QTableWidgetItem(value)
                 item.previous_name = value
-                if j != (self.parent_frame.tableWidget_records.columnCount() - 1):
+                if j != (
+                    self.parent_frame.tableWidget_records.columnCount() - 1
+                ):
                     item.setFlags(item.flags() & ~Qt.ItemIsEditable)
                 self.parent_frame.tableWidget_records.setItem(i, j, item)
 
@@ -124,13 +142,16 @@ class Records:
                 # header.customContextMenuRequested.connect(self.handleHeaderMenu)
 
         self.parent_frame.tableWidget_records.sortByColumn(
-            1, Qt.SortOrder.AscendingOrder)
+            1, Qt.SortOrder.AscendingOrder
+        )
 
         # header = self.parent_frame.tableWidget_records.horizontalHeader()
         self.parent_frame.tableWidget_records.setContextMenuPolicy(
-            Qt.CustomContextMenu)
+            Qt.CustomContextMenu
+        )
         self.parent_frame.tableWidget_records.customContextMenuRequested.connect(
-            self.handleHeaderMenu)
+            self.handleHeaderMenu
+        )
 
     # ----------------------------------------------------------------------
     def get_metadata(self, filename: str, light: bool = True) -> None:
@@ -149,8 +170,9 @@ class Records:
         montage = file.header['montage']
         channels = file.header['channels']
         filename = filename.replace('.h5', '')
-        created = datetime.fromtimestamp(
-            file.header['datetime']).strftime("%x %X")
+        created = datetime.fromtimestamp(file.header['datetime']).strftime(
+            "%x %X"
+        )
         _, samples = file.header['shape']
         sample_rate = file.header['sample_rate']
         duration = str(timedelta(seconds=int(samples / sample_rate)))
@@ -163,7 +185,15 @@ class Records:
             markers = []
 
         file.close()
-        return [duration, created, filename, montage, channels, annotations, markers]
+        return [
+            duration,
+            created,
+            filename,
+            montage,
+            channels,
+            annotations,
+            markers,
+        ]
 
     # ----------------------------------------------------------------------
     def load_file(self, item) -> None:
@@ -172,14 +202,26 @@ class Records:
 
         self.current_signal = item.row()
         name = self.parent_frame.tableWidget_records.item(
-            item.row(), 2).text()
+            item.row(), 2
+        ).text()
 
-        duration, datetime, _, montage, electrodes, annotations, markers = self.get_metadata(
-            f"{name}.h5", light=False)
+        (
+            duration,
+            datetime,
+            _,
+            montage,
+            electrodes,
+            annotations,
+            markers,
+        ) = self.get_metadata(f"{name}.h5", light=False)
 
         electrodes = list(electrodes.values())
-        electrodes = '\n'.join([', '.join(electrodes[n:n + 8])
-                                for n in range(0, len(electrodes), 8)])
+        electrodes = '\n'.join(
+            [
+                ', '.join(electrodes[n : n + 8])
+                for n in range(0, len(electrodes), 8)
+            ]
+        )
 
         self.parent_frame.label_record_name.setText(name)
         self.parent_frame.label_record_primary.setText(f" [{duration}]")
@@ -188,15 +230,20 @@ class Records:
         self.parent_frame.label_record_montage.setText(montage)
 
         self.parent_frame.label_record_name.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
         self.parent_frame.label_record_primary.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
         self.parent_frame.label_record_datetime.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
         self.parent_frame.label_record_channels.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
         self.parent_frame.label_record_montage.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
 
         self.core.annotations.bulk_annotations(annotations)
         self.core.annotations.bulk_markers(markers)
@@ -206,18 +253,18 @@ class Records:
         # self.parent_frame.tableWidget_annotations.setColumnCount(3)
 
         # self.parent_frame.tableWidget_annotations.setHorizontalHeaderLabels(
-            # ['Onset', 'Duration', 'Description'])
+        # ['Onset', 'Duration', 'Description'])
 
         # for row, annotation in enumerate(annotations):
-            # self.parent_frame.tableWidget_annotations.insertRow(row)
-            # onset, duration, description = annotation
+        # self.parent_frame.tableWidget_annotations.insertRow(row)
+        # onset, duration, description = annotation
 
-            # item = QTableWidgetItem(f"{round(onset, 2)}")
-            # self.parent_frame.tableWidget_annotations.setItem(row, 0, item)
-            # item = QTableWidgetItem(f"{duration}")
-            # self.parent_frame.tableWidget_annotations.setItem(row, 1, item)
-            # item = QTableWidgetItem(description)
-            # self.parent_frame.tableWidget_annotations.setItem(row, 2, item)
+        # item = QTableWidgetItem(f"{round(onset, 2)}")
+        # self.parent_frame.tableWidget_annotations.setItem(row, 0, item)
+        # item = QTableWidgetItem(f"{duration}")
+        # self.parent_frame.tableWidget_annotations.setItem(row, 1, item)
+        # item = QTableWidgetItem(description)
+        # self.parent_frame.tableWidget_annotations.setItem(row, 2, item)
 
         self.parent_frame.horizontalSlider_record.setValue(0)
         self.parent_frame.widget_record.show()
@@ -226,11 +273,14 @@ class Records:
     # ----------------------------------------------------------------------
     def get_offset(self) -> float:
         """The offset for slider animation."""
-        h, m, s = self.parent_frame.label_record_primary.text()[
-            2:-1].split(':')
+        h, m, s = self.parent_frame.label_record_primary.text()[2:-1].split(
+            ':'
+        )
         seconds = int(h) * 60 * 60 + int(m) * 60 + int(s)
-        value = self.parent_frame.horizontalSlider_record.value(
-        ) / self.parent_frame.horizontalSlider_record.maximum()
+        value = (
+            self.parent_frame.horizontalSlider_record.value()
+            / self.parent_frame.horizontalSlider_record.maximum()
+        )
         return seconds * value
 
     # ----------------------------------------------------------------------
@@ -240,9 +290,11 @@ class Records:
         self.start_play = datetime.now()
 
         self.parent_frame.label_time_current.setStyleSheet(
-            "*{font-family: 'mono'}")
+            "*{font-family: 'mono'}"
+        )
         self.parent_frame.label_time_current.setText(
-            str(offset - timedelta(microseconds=offset.microseconds)))
+            str(offset - timedelta(microseconds=offset.microseconds))
+        )
 
     # ----------------------------------------------------------------------
     def stream_record(self, toggled) -> None:
@@ -251,8 +303,12 @@ class Records:
 
         if toggled:
             QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-            self.record_reader = HDF5Reader(os.path.join(
-                self.records_dir, f'{self.parent_frame.label_record_name.text()}.h5'))
+            self.record_reader = HDF5Reader(
+                os.path.join(
+                    self.records_dir,
+                    f'{self.parent_frame.label_record_name.text()}.h5',
+                )
+            )
             self.record_reader.eeg  # cached
             self.record_reader.aux  # cached
             QApplication.restoreOverrideCursor()
@@ -264,13 +320,15 @@ class Records:
             self.timer.timeout.connect(self.update_timer)
             self.timer.start()
             self.parent_frame.pushButton_play_signal.setIcon(
-                QIcon.fromTheme('media-playback-pause'))
+                QIcon.fromTheme('media-playback-pause')
+            )
 
         else:
             self.record_reader.close()
             self.timer.stop()
             self.parent_frame.pushButton_play_signal.setIcon(
-                QIcon.fromTheme('media-playback-start'))
+                QIcon.fromTheme('media-playback-start')
+            )
 
     # ----------------------------------------------------------------------
     def update_timer(self) -> None:
@@ -278,20 +336,27 @@ class Records:
         now = datetime.now()
         delta = now - self.start_play + timedelta(seconds=self.get_offset())
 
-        h, m, s = self.parent_frame.label_record_primary.text()[
-            2:-1].split(':')
+        h, m, s = self.parent_frame.label_record_primary.text()[2:-1].split(
+            ':'
+        )
         seconds = int(h) * 60 * 60 + int(m) * 60 + int(s)
 
-        value = self.parent_frame.horizontalSlider_record.maximum() / \
-            ((seconds / delta.total_seconds()))
+        value = self.parent_frame.horizontalSlider_record.maximum() / (
+            (seconds / delta.total_seconds())
+        )
         self.parent_frame.horizontalSlider_record.setValue(int(value))
 
-        end_streaming = int((self.record_reader.eeg.shape[1] * self.parent_frame.horizontalSlider_record.value(
-        )) / self.parent_frame.horizontalSlider_record.maximum())
+        end_streaming = int(
+            (
+                self.record_reader.eeg.shape[1]
+                * self.parent_frame.horizontalSlider_record.value()
+            )
+            / self.parent_frame.horizontalSlider_record.maximum()
+        )
 
         if samples := end_streaming - self.start_streaming:
             if samples < 0:
-                samples = (4 * self.record_reader.eeg.shape[1] / 1000)
+                samples = 4 * self.record_reader.eeg.shape[1] / 1000
 
             # print(samples, [max([end_streaming - samples, 0]), end_streaming])
             samples = int(samples)
@@ -302,13 +367,22 @@ class Records:
                 'samples': samples,
             }
 
-            data_ = {'context': context,
-                     'data': (self.record_reader.eeg[:, max([end_streaming - samples, 0]): end_streaming],
-                              self.record_reader.aux[:, max([end_streaming - samples, 0]): end_streaming]),
-                     }
+            data_ = {
+                'context': context,
+                'data': (
+                    self.record_reader.eeg[
+                        :, max([end_streaming - samples, 0]) : end_streaming
+                    ],
+                    self.record_reader.aux[
+                        :, max([end_streaming - samples, 0]) : end_streaming
+                    ],
+                ),
+            }
             self.start_streaming = end_streaming
 
-            if produser := getattr(self.core.thread_kafka, 'produser', False):
+            if produser := getattr(
+                self.core.thread_kafka, 'produser', False
+            ):
                 produser.send('eeg', data_)
 
     # ----------------------------------------------------------------------
@@ -334,11 +408,27 @@ class Records:
             self.timer.start()
 
             if '--local' in sys.argv:
-                self.subprocess_script = run_subprocess([sys.executable, os.path.join(
-                    os.environ['BCISTREAM_ROOT'], 'kafka_scripts', 'record.py')])
+                self.subprocess_script = run_subprocess(
+                    [
+                        sys.executable,
+                        os.path.join(
+                            os.environ['BCISTREAM_ROOT'],
+                            'kafka_scripts',
+                            'record.py',
+                        ),
+                    ]
+                )
             else:
-                self.subprocess_script = run_subprocess([sys.executable, os.path.join(
-                    os.environ['BCISTREAM_HOME'], 'kafka_scripts', 'record.py')])
+                self.subprocess_script = run_subprocess(
+                    [
+                        sys.executable,
+                        os.path.join(
+                            os.environ['BCISTREAM_HOME'],
+                            'kafka_scripts',
+                            'record.py',
+                        ),
+                    ]
+                )
         else:
             self.recording_status = None
             self.timer.stop()
@@ -350,13 +440,16 @@ class Records:
     def handleHeaderMenu(self, pos):
         """"""
         row = self.parent_frame.tableWidget_records.currentRow()
-        filename = self.parent_frame.tableWidget_records.item(row, 2).text()
+        if self.parent_frame.tableWidget_records.item(row, 2) is None:
+            return
 
+        filename = self.parent_frame.tableWidget_records.item(row, 2).text()
         menu = QMenu()
 
         jupyter_action = QAction('Open with Juypter Lab')
         jupyter_action.triggered.connect(
-            lambda: self.open_with_jupyter(filename))
+            lambda: self.open_with_jupyter(filename)
+        )
         menu.addAction(jupyter_action)
 
         edf_action = QAction('Export to EDF')
@@ -365,7 +458,8 @@ class Records:
 
         numpy_action = QAction('Export to Numpy (npy)')
         numpy_action.triggered.connect(
-            lambda: self.export_to_numpy(filename))
+            lambda: self.export_to_numpy(filename)
+        )
         menu.addAction(numpy_action)
 
         menu.addSeparator()
@@ -403,10 +497,12 @@ class Records:
         """"""
         h5 = os.path.join(self.records_dir, f'{filename}.h5')
         notebook = os.path.join(
-            os.environ['BCISTREAM_ROOT'], 'assets', 'jupyter.ipynb')
+            os.environ['BCISTREAM_ROOT'], 'assets', 'jupyter.ipynb'
+        )
 
         notebook_dir = os.path.join(
-            os.environ['BCISTREAM_HOME'], 'notebooks', 'records')
+            os.environ['BCISTREAM_HOME'], 'notebooks', 'records'
+        )
         if not os.path.exists(notebook_dir):
             os.mkdir(notebook_dir)
 
@@ -416,10 +512,13 @@ class Records:
             with open(notebook_template, 'r') as file:
                 content = file.read()
                 content = content.replace(
-                    '{{BCI-FRAMEWORK:FILENAME}}', os.path.relpath(h5, notebook_dir))
+                    '{{BCI-FRAMEWORK:FILENAME}}',
+                    os.path.relpath(h5, notebook_dir),
+                )
             with open(notebook_file, 'w') as file:
                 file.write(content)
 
-        command = f"jupyter-lab --notebook-dir='{notebook_dir}' {notebook_file}"
+        command = (
+            f"jupyter-lab --notebook-dir='{notebook_dir}' {notebook_file}"
+        )
         os.popen(command)
-
